#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib/gi18n.h>
#include <dbus/dbus-glib.h>
#include <ocr-dbus-client.h>

#include "ocr-dbus-client-binding.h"

#define OCR_DBUS_CLIENT_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), OCR_TYPE_DBUS_CLIENT, OcrDBusClientPrivate))

G_DEFINE_TYPE (OcrDBusClient, ocr_dbus_client, G_TYPE_OBJECT);

struct _OcrDBusClientPrivate
{
  DBusGProxy *proxy;
};

static void
ocr_dbus_client_dispose (GObject *gobject)
{
  OcrDBusClient        *self;
  OcrDBusClientPrivate *priv;
  static gboolean       first_run = TRUE;

  g_return_if_fail (OCR_IS_DBUS_CLIENT (gobject));

  self = OCR_DBUS_CLIENT (gobject);
  priv = self->priv;

  if (first_run)
  {
    g_object_unref (priv->proxy);

    first_run = FALSE;
  }

  G_OBJECT_CLASS (ocr_dbus_client_parent_class)->dispose (gobject);
}

static void
ocr_dbus_client_finalize (GObject *gobject)
{
  g_return_if_fail (OCR_IS_DBUS_CLIENT (gobject));

  G_OBJECT_CLASS (ocr_dbus_client_parent_class)->finalize (gobject);
}

static void
ocr_dbus_client_class_init (OcrDBusClientClass *klass)
{
  GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
  GError       *error = NULL;

  g_type_class_add_private (gobject_class, sizeof (OcrDBusClientPrivate));

  gobject_class->dispose = ocr_dbus_client_dispose;
  gobject_class->finalize = ocr_dbus_client_finalize;

  /* no need to free the following pointer */
  klass->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
  if (klass->connection == NULL)
  {
    g_warning ("Unable to connect to dbus: %s", error->message);
    g_error_free (error);
    return;
  }
}

static void
ocr_dbus_client_init (OcrDBusClient *self)
{
  OcrDBusClientPrivate *priv;
  OcrDBusClientClass *klass = OCR_DBUS_CLIENT_GET_CLASS (self);

  g_return_if_fail (OCR_IS_DBUS_CLIENT (self));

  self->priv = OCR_DBUS_CLIENT_GET_PRIVATE (self);
  priv = self->priv;

  priv->proxy = dbus_g_proxy_new_for_name (klass->connection,
					   "net.sourceforge.projects.ocrgui",
					   "/net/sourceforge/projects/ocrgui",
					   "net.sourceforge.projects.ocrgui");
}

gboolean
ocr_dbus_client_test (OcrDBusClient *self)
{
  OcrDBusClientPrivate *priv;
  GError *error = NULL;

  g_return_val_if_fail (OCR_IS_DBUS_CLIENT (self), FALSE);

  priv = self->priv;

  if (!net_sourceforge_projects_ocrgui_test (priv->proxy, &error))
  {
    //g_warning ("No service found: %s", error->message);
    g_clear_error (&error);
    return FALSE;
  }

  return TRUE;
}

gboolean
ocr_dbus_client_load_image_file (OcrDBusClient *self,
				 gchar         *file)
{
  OcrDBusClientPrivate *priv;
  GError               *error = NULL;

  g_return_val_if_fail (OCR_IS_DBUS_CLIENT (self), FALSE);

  priv = self->priv;

  if (!dbus_g_proxy_call (priv->proxy,
			  "LoadImageFile",
			  &error, 
			  G_TYPE_STRING, file, 
			  G_TYPE_INVALID, 
			  G_TYPE_INVALID))
  {
    g_warning ("Remote method failed: %s\n", error->message);
    g_error_free (error);
    return FALSE;
  }

  return TRUE;
}
