#ifndef __OCR_PANEL_H__
#define __OCR_PANEL_H__

#include <gtk/gtk.h>
#include "ocr-preferences.h"

#define OCR_TYPE_PANEL              (ocr_panel_get_type())
#define OCR_PANEL(obj)              (G_TYPE_CHECK_INSTANCE_CAST ((obj), OCR_TYPE_PANEL, OcrPanel))
#define OCR_IS_PANEL(obj)           (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OCR_TYPE_PANEL))
#define OCR_PANEL_CLASS(klass)      (G_TYPE_CHECK_CLASS_CAST ((klass), OCR_TYPE_PANEL, OcrPanelClass))
#define OCR_IS_PANEL_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), OCR_TYPE_PANEL))
#define OCR_PANEL_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), OCR_TYPE_PANEL, OcrPanelClass))

#define OCR_PANEL_FONT_SELECTION_DIALOG_KEY "ocr-panel-font-selection-dialog-key"
#define OCR_PANEL_SAVE_TEXT_DIALOG_KEY "ocr-panel-save-text-dialog-key"

#define IMAGE_ZOOM_MIN 1
#define IMAGE_ZOOM_MAX 500
#define IMAGE_ZOOM_IN_OUT 15
#define FONT_SIZE_MIN 1
#define FONT_SIZE_MAX 100

typedef enum {
  OCR_PANEL_STATE_OCR_PERFORMED        = 1 << 0,
  OCR_PANEL_STATE_TEXT_BUFFER_MODIFIED = 1 << 1
} OcrPanelState;

#define OCR_PANEL_STATE(panel) 			(OCR_PANEL (panel)->state)
#define OCR_PANEL_OCR_PERFORMED(panel) 		((OCR_PANEL_STATE (panel) & OCR_PANEL_STATE_OCR_PERFORMED) != 0)
#define OCR_PANEL_TEXT_BUFFER_MODIFIED(panel) 	((OCR_PANEL_STATE (panel) & OCR_PANEL_STATE_TEXT_BUFFER_MODIFIED) != 0)
#define OCR_PANEL_SET_STATE(panel, state) 	G_STMT_START{ (OCR_PANEL_STATE (panel) |= (state)); }G_STMT_END
#define OCR_PANEL_UNSET_STATE(panel, state) 	G_STMT_START{ (OCR_PANEL_STATE (panel) &= ~(state)); }G_STMT_END

typedef struct _OcrPanel            OcrPanel;
typedef struct _OcrPanelClass       OcrPanelClass;
typedef struct _OcrPanelPrivate     OcrPanelPrivate;

struct _OcrPanel
{
//  GtkHPaned parent_instance;
  GtkVBox parent_instance;

  OcrPanelPrivate *priv;
  OcrPanelState    state;
};

struct _OcrPanelClass
{
//  GtkHPanedClass parent_class;
  GtkVBoxClass parent_class;
};

GType			 ocr_panel_get_type				(void);
GtkWidget		*ocr_panel_get_image_zoom			(OcrPanel *self);
GtkWidget		*ocr_panel_get_font_size			(OcrPanel *self); 
GtkWidget		*ocr_panel_get_main_window			(OcrPanel *self);
GtkWidget		*ocr_panel_get_imageview			(OcrPanel *self);
GtkWidget		*ocr_panel_get_textview				(OcrPanel *self);
GObject			*ocr_panel_get_textbuffer			(OcrPanel *self);
GObject			*ocr_panel_get_image_file			(OcrPanel *self);
gchar			*ocr_panel_get_image_file_display_name		(OcrPanel *self);
OcrPanelState		 ocr_panel_state				(OcrPanel *self);
void			 ocr_panel_destroy_selection_font_dialog 	(OcrPanel *self);
void			 ocr_panel_set_font				(OcrPanel    *self,
									 const gchar *font_name);
void			 ocr_panel_destroy_save_text_dialog 		(OcrPanel *self);
void			 ocr_panel_change_layout			(OcrPanel             *self,
									 OcrPreferencesLayout  layout);
void			 ocr_panel_show_paned				(OcrPanel *self);

#endif /* __OCR_PANEL_H__ */

