#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib/gi18n.h>

#include "ocr-utils.h"

gboolean 
ocr_utils_load_file (GFile  *file, 
                     gchar **content)
{
  gsize   length;
  GError *error = NULL;

  g_return_val_if_fail (G_IS_FILE (file), FALSE);
 
  g_file_load_contents (file,
			NULL,
			content,
			&length,
			NULL,
			&error);

  if (error != NULL)
  {
    GFileInfo *file_info;
    gchar     *message;

    file_info = g_file_query_info (file,
				   G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME,
				   G_FILE_QUERY_INFO_NONE,
				   NULL,
				   NULL);

    message = g_strdup_printf (_("Can't load file «%s»:\n%s"),
			       g_file_info_get_display_name (file_info),
			       error->message);

    ocr_utils_message (_("Error loading file"),
		       message,
		       GTK_MESSAGE_ERROR);

    g_object_unref (file_info);
    g_free (message);
    g_clear_error (&error);
    return FALSE;
  }
  else
    return TRUE;
/*
  if (!g_file_test (file_name, G_FILE_TEST_EXISTS))
  {
    message = g_strdup_printf ("File does not exist: %s",
			       file_name);

    ocr_utils_message ("Error",
                       message, 
                       GTK_MESSAGE_ERROR);

    g_free (message);
    return FALSE;
  }
  
  error = NULL;
  g_file_get_contents (file_name,
		       content,
		       &length,
		       &error);

  if (error != NULL)
  {
    message = g_strdup_printf ("Error loading file %s: %s",
			       file_name,
			       error->message);

    ocr_utils_message ("Error",
		       message,
		       GTK_MESSAGE_ERROR);

    g_clear_error (&error);
    g_free (message);
    return FALSE;
  }
  else
    return TRUE;
    */
}

gboolean
ocr_utils_write_file (const gchar *file_name,
		      const gchar *content)
{
  gchar  *message;
  GError *error;

  g_return_val_if_fail (file_name != NULL, FALSE);
  g_return_val_if_fail (content != NULL, FALSE);

  error = NULL;
  g_file_set_contents (file_name,
		       content,
		       -1,
		       &error);

  if (error != NULL)
  {
    message = g_strdup_printf (_("Error writing file «%s»: %s"),
			       file_name,
			       error->message);

    ocr_utils_message (_("Error"),
		       message,
		       GTK_MESSAGE_ERROR);

    g_clear_error (&error);
    g_free (message);
    return FALSE;
  } 
  else
    return TRUE;
}

const gchar *
ocr_utils_get_home_dir (void)
{
  const char *homedir = g_getenv ("HOME");

  if (!homedir)
    homedir = g_get_home_dir ();

  return homedir;
}

void
ocr_utils_message (const gchar    *title,
		   const gchar    *message,
		   GtkMessageType  type)
{
  GtkWidget *dialog;

  dialog = gtk_message_dialog_new (NULL,
				   GTK_DIALOG_MODAL,
				   type,
				   GTK_BUTTONS_CLOSE,
				   title,
				   NULL);
  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
					    message,
					    NULL);

  gtk_dialog_run (GTK_DIALOG (dialog));
  gtk_widget_destroy (dialog);
}

gboolean 
ocr_utils_question (const gchar *title,
		    const gchar *message)
{
  GtkWidget *dialog;
  gboolean   result;

  dialog = gtk_message_dialog_new (NULL,
				   GTK_DIALOG_MODAL,
				   GTK_MESSAGE_QUESTION,
				   GTK_BUTTONS_YES_NO,
				   title,
				   NULL);
  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
					    message,
					    NULL);

  result = (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES);
  gtk_widget_destroy (dialog);

  return result;
}

void
ocr_utils_free_string_list_content (GList *list,
				    guint  length)
{
  guint  max;
  gchar *str;
  gint   i;
  
  g_return_if_fail (list != NULL);
  g_return_if_fail (length == -1 || length > 0);

  if (length > 0)
    max = length;
  else
    max = g_list_length (list);

  for (i = 0; i < max; i++)
  {
    str = g_list_nth_data (list,
			   i);

    g_free (str);
  }
}
